@@ -2,7 +2,7 @@ import os.path
 
 from git import Repo
 
-from shulkr.git import get_blob
+from shulkr.git import get_blob, head_has_commits
 from shulkr.java import JavaAnalyzationError
 from shulkr.java import get_renamed_variables, undo_variable_renames
 from shulkr.minecraft.source import generate_sources
@@ -14,6 +14,8 @@ def undo_renames(repo: Repo) -> None:
 	commit2 = None  # working tree
 	diff_index = commit1.diff(commit2)
 
+	updated_count = 0
+
 	# For each file changed (in reverse, with indices, so we can remove elements
 	# in the for loop)
 	for diff in diff_index:
@@ -39,7 +41,9 @@ def undo_renames(repo: Repo) -> None:
 			with open(p, 'w') as f:
 				f.write(updated_target)
 
-			print(f'Updated {diff.a_path}')
+			updated_count += 1
+
+	print(f'+ Updated {updated_count} files')
 
 
 def commit_version(
@@ -50,11 +54,11 @@ def commit_version(
 ) -> None:
 
 	commit_msg = message_template.strip().replace('{}', str(version))
-	if undo_renamed_vars and len(repo.iter_commits()) > 0:
+	if undo_renamed_vars and head_has_commits(repo):
 		commit_msg += '\n\nRenamed variables reverted'
 
-	repo.index.add('client', 'server')
-	repo.index.commit(commit_msg)
+	repo.git.add('client', 'server')
+	repo.git.commit(message=commit_msg)
 
 
 def tag_version(repo: Repo, version: Version) -> None:
@@ -74,7 +78,7 @@ def create_version(
 	generate_sources(repo, version)
 
 	# 2. If there are any previous versions, undo the renamed variables
-	if undo_renamed_vars and len(repo.iter_commits()) > 0:
+	if undo_renamed_vars and head_has_commits(repo):
 		print('Undoing renamed variables')
 		undo_renames(repo)
 
