@@ -3,14 +3,15 @@ import sys
 
 from git import InvalidGitRepositoryError, Repo
 
-from shulkr import parse_args, create_version
+from shulkr import create_version
+from shulkr.arguments import parse_args
 from shulkr.minecraft.version import NoSuchVersionError, Version, load_manifest
 
 
 def main_uncaught() -> None:
 	load_manifest()
 
-	args = parse_args()
+	args = parse_args(sys.argv[1:])
 
 	repo_path = os.path.join(
 		os.getcwd(),
@@ -18,12 +19,17 @@ def main_uncaught() -> None:
 	)
 
 	try:
-		ranges = [Version.pattern(p) for p in args.version]
-		versions = [version for range in ranges for version in range]
-		versions.sort()
+		versions = Version.patterns(args.version)
 	except NoSuchVersionError as e:
 		print(e, file=sys.stderr)
 		sys.exit(1)
+	except ValueError as e:
+		print(e, file=sys.stderr)
+		sys.exit(2)
+
+	if len(versions) == 0:
+		print('No versions selected', file=sys.stderr)
+		sys.exit(3)
 
 	if not os.path.exists(repo_path):
 		print(f'Creating {repo_path}')
@@ -40,7 +46,8 @@ def main_uncaught() -> None:
 			repo,
 			version_id,
 			args.undo_renamed_vars,
-			args.message
+			args.message,
+			args.tag
 		)
 
 
