@@ -4,6 +4,7 @@ import subprocess
 
 from git import Repo
 
+from ..git import head_has_commits
 from .version import Version
 
 
@@ -43,7 +44,8 @@ def generate_sources(repo: Repo, version: Version) -> None:
 				shutil.rmtree(dest_src_dir)
 
 			# Make top-level destination directory
-			os.makedirs(dest_dir)
+			if not os.path.exists(dest_dir):
+				os.makedirs(dest_dir)
 
 			# Move the generated source code to $dest_dir/src
 			shutil.move(
@@ -52,10 +54,14 @@ def generate_sources(repo: Repo, version: Version) -> None:
 			)
 
 	except BaseException as e:
-		# Undo src/ deletion
-		print('Resetting working tree')
-		if len(repo.iter_commits()) > 0:
+		# Undo src/ deletions
+		if head_has_commits(repo):
 			repo.git.restore('client', 'server')
+		else:
+			for env in ('client', 'server'):
+				path = os.path.join(repo.working_tree_dir, env, 'src')
+				if os.path.exists(path):
+					shutil.rmtree(path)
 
 		raise e
 
